0.2.0a1.dev29 (2022-04-01)
==========================

Documentation
-------------
- Updated documentation of ``codestare.async_utils`` module


0.2.0a1.dev22 (2022-03-25)
==========================

Bug Fixes
---------
- Fixed bug introduced by changed json backend URL that was not correctly propagated during client runtime


0.1.0 (2022-03-25)
==================

New Features
------------
- Auto reconnect when master node shuts down

Bug Fixes
---------
- Fixed package name refactoring breaking some imports

- Fixed bug introduced by changed json backend URL that was not correctly propagated during client runtime

- Fixed additional errors caused by renaming


0.1.0 (2022-03-25)
==================

New Features
------------
- Auto reconnect when master node shuts down

Bug Fixes
---------
- Fixed package name refactoring breaking some imports

- Fixed additional errors caused by renaming


0.2.0.a1.dev13 (2022-02-16)
===========================

New Features
------------
- Auto reconnect when master node shuts down

Bug Fixes
---------
- Fixed package name refactoring breaking some imports

- Fixed additional errors caused by renaming


0.2.0.a1.dev3 (2022-02-02)
==========================

Documentation
-------------
- Setting up documentation and Changelog


